@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A MessagePack converting processor
 
-our $VERSION = '1.111750'; # VERSION
+our $VERSION = '1.111810'; # VERSION
 
 use Moose;
 extends 'DataFlow::Proc::Converter';
@@ -13,11 +13,9 @@ extends 'DataFlow::Proc::Converter';
 use namespace::autoclean;
 use Data::MessagePack;
 
-has '+policy' => (
-    'default' => sub {
-        return shift->direction eq 'CONVERT_TO' ? 'ArrayRef' : 'Scalar';
-    },
-);
+sub _policy {
+    return shift->direction eq 'CONVERT_TO' ? 'ArrayRef' : 'Scalar';
+}
 
 has '+converter' => (
     lazy    => 1,
@@ -37,24 +35,20 @@ has '+converter' => (
 
 has '+converter_opts' => ( 'init_arg' => 'msgpack_opts', );
 
-has '+converter_subs' => (
-    'lazy'    => 1,
-    'default' => sub {
-        my $self = shift;
+sub _build_subs {
+    my $self = shift;
 
-        my $subs = {
-            'TO_MSGPACK' => sub {
-                return $self->msgpack->pack($_);
-            },
-            'FROM_MSGPACK' => sub {
-                return $self->msgpack->unpack($_);
-            },
-        };
+    my $subs = {
+        'TO_MSGPACK' => sub {
+            return $self->msgpack->pack($_);
+        },
+        'FROM_MSGPACK' => sub {
+            return $self->msgpack->unpack($_);
+        },
+    };
 
-        return $subs;
-    },
-    'init_arg' => undef,
-);
+    return $subs;
+}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -72,7 +66,7 @@ DataFlow::Proc::MessagePack - A MessagePack converting processor
 
 =head1 VERSION
 
-version 1.111750
+version 1.111810
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
 
